@@ -42,6 +42,11 @@ class ListRulesRequest(RpcRequest):
 
 	def set_NextToken(self, NextToken):  # String
 		self.add_query_param('NextToken', NextToken)
+	def get_Direction(self): # String
+		return self.get_query_params().get('Direction')
+
+	def set_Direction(self, Direction):  # String
+		self.add_query_param('Direction', Direction)
 	def get_RuleIds(self): # Array
 		return self.get_query_params().get('RuleIds')
 
