@@ -47,7 +47,7 @@ class UpdateServerGroupAttributeRequest(RpcRequest):
 	def set_HealthCheckConfig(self, HealthCheckConfig):  # Struct
 		if HealthCheckConfig.get('HealthCheckCodes') is not None:
 			for index1, value1 in enumerate(HealthCheckConfig.get('HealthCheckCodes')):
-				self.add_query_param('HealthCheckConfig.HealthCheckCodes' + str(index1 + 1), value1)
+				self.add_query_param('HealthCheckConfig.HealthCheckCodes.' + str(index1 + 1), value1)
 		if HealthCheckConfig.get('HealthCheckEnabled') is not None:
 			self.add_query_param('HealthCheckConfig.HealthCheckEnabled', HealthCheckConfig.get('HealthCheckEnabled'))
 		if HealthCheckConfig.get('HealthCheckTimeout') is not None:
@@ -70,7 +70,7 @@ class UpdateServerGroupAttributeRequest(RpcRequest):
 			self.add_query_param('HealthCheckConfig.HealthCheckInterval', HealthCheckConfig.get('HealthCheckInterval'))
 		if HealthCheckConfig.get('HealthCheckHttpCodes') is not None:
 			for index1, value1 in enumerate(HealthCheckConfig.get('HealthCheckHttpCodes')):
-				self.add_query_param('HealthCheckConfig.HealthCheckHttpCodes' + str(index1 + 1), value1)
+				self.add_query_param('HealthCheckConfig.HealthCheckHttpCodes.' + str(index1 + 1), value1)
 		if HealthCheckConfig.get('HealthCheckHttpVersion') is not None:
 			self.add_query_param('HealthCheckConfig.HealthCheckHttpVersion', HealthCheckConfig.get('HealthCheckHttpVersion'))
 		if HealthCheckConfig.get('HealthCheckConnectPort') is not None:
@@ -85,6 +85,11 @@ class UpdateServerGroupAttributeRequest(RpcRequest):
 
 	def set_ServerGroupId(self, ServerGroupId):  # String
 		self.add_query_param('ServerGroupId', ServerGroupId)
+	def get_ServiceName(self): # String
+		return self.get_query_params().get('ServiceName')
+
+	def set_ServiceName(self, ServiceName):  # String
+		self.add_query_param('ServiceName', ServiceName)
 	def get_StickySessionConfig(self): # Struct
 		return self.get_query_params().get('StickySessionConfig')
 
@@ -102,3 +107,11 @@ class UpdateServerGroupAttributeRequest(RpcRequest):
 
 	def set_DryRun(self, DryRun):  # Boolean
 		self.add_query_param('DryRun', DryRun)
+	def get_UchConfig(self): # Struct
+		return self.get_query_params().get('UchConfig')
+
+	def set_UchConfig(self, UchConfig):  # Struct
+		if UchConfig.get('Type') is not None:
+			self.add_query_param('UchConfig.Type', UchConfig.get('Type'))
+		if UchConfig.get('Value') is not None:
+			self.add_query_param('UchConfig.Value', UchConfig.get('Value'))
